==> haskell-sourcemap-0.1.7-242-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sourcemap
version:              0.1.7
visibility:           public
id:                   sourcemap-0.1.7-FcO7Clss3D7IeI3iRHHNoJ
key:                  sourcemap-0.1.7-FcO7Clss3D7IeI3iRHHNoJ
license:              BSD-3-Clause
copyright:            2012 Chris Done
maintainer:           Jens Petersen <juhpetersen@gmail.com>
author:               Chris Done
stability:            alpha
synopsis:
    Implementation of source maps as proposed by Google and Mozilla.

description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>

category:             Development
abi:                  ef4267eda60e3d6287d87f3cde591f57
exposed:              True
exposed-modules:      SourceMap SourceMap.Types
hidden-modules:       VLQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sourcemap
hs-libraries:         HSsourcemap-0.1.7-FcO7Clss3D7IeI3iRHHNoJ
depends:
    aeson-2.1.2.1-9HQxGJjc2cdAmcsURaBDXL
    attoparsec-0.14.4-2WnTlN46elo3llwbGCF7aS base-4.17.2.1
    bytestring-0.11.5.3 process-1.6.18.0 text-2.0.2
    unordered-containers-0.2.20-3czZ5Len2GTFaAkRxFZe7E
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html:         /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sourcemap-0.1.7-243-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sourcemap
version:              0.1.7
visibility:           public
id:                   sourcemap-0.1.7-LcaGyTHHtaQEnP8T46RYh1
key:                  sourcemap-0.1.7-LcaGyTHHtaQEnP8T46RYh1
license:              BSD-3-Clause
copyright:            2012 Chris Done
maintainer:           Jens Petersen <juhpetersen@gmail.com>
author:               Chris Done
stability:            alpha
synopsis:
    Implementation of source maps as proposed by Google and Mozilla.

description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>

category:             Development
abi:                  46d5333a362e5eb2f34fb955320843ae
exposed:              True
exposed-modules:      SourceMap SourceMap.Types
hidden-modules:       VLQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sourcemap-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sourcemap
hs-libraries:         HSsourcemap-0.1.7-LcaGyTHHtaQEnP8T46RYh1
depends:
    aeson-2.1.2.1-LDc25PpdH5WHlLB8Mcp2Rh
    attoparsec-0.14.4-AS2Ju05FAjs55rPAuL3miO base-4.17.2.1
    bytestring-0.11.5.3 process-1.6.18.0 text-2.0.2
    unordered-containers-0.2.20-Cw2Ec4BgC4sInKE4e5RLSk
    utf8-string-1.0.2-FAQSGuIUGqDKZx6mH04y15

haddock-interfaces:   /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html:         /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
